more fixes
diff --git a/googletest/CMakeLists.txt b/googletest/CMakeLists.txt
index 615b071..4f340bb 100644
--- a/googletest/CMakeLists.txt
+++ b/googletest/CMakeLists.txt
@@ -262,7 +262,7 @@
   endif()
 
   cxx_executable_with_flags(
-    gtest_catch_exceptions_ex_test_
+    googletest-catch-exceptions-ex-test_
     "${cxx_exception}"
     gtest_main
     test/googletest-catch-exceptions-test_.cc)
diff --git a/googletest/test/googletest-catch-exceptions-test.py b/googletest/test/googletest-catch-exceptions-test.py
index 0bd4366..5f13efa 100755
--- a/googletest/test/googletest-catch-exceptions-test.py
+++ b/googletest/test/googletest-catch-exceptions-test.py
@@ -31,7 +31,7 @@
 """Tests Google Test's exception catching behavior.
 
 This script invokes googletest-catch-exceptions-test_ and
-gtest_catch_exceptions_ex_test_ (programs written with
+googletest-catch-exceptions-ex-test_ (programs written with
 Google Test) and verifies their output.
 """
 
@@ -45,7 +45,7 @@
 NO_CATCH_EXCEPTIONS_FLAG = FLAG_PREFIX + 'catch_exceptions=0'
 FILTER_FLAG = FLAG_PREFIX + 'filter'
 
 # Path to the gtest_catch_exceptions_ex_test_ binary, compiled with
 # exceptions enabled.
 EX_EXE_PATH = gtest_test_utils.GetTestExecutablePath(
     'googletest-catch-exceptions-ex-test_')
@@ -45,7 +45,7 @@
 FILTER_FLAG = FLAG_PREFIX + 'filter'
 
-# Path to the gtest_catch_exceptions_ex_test_ binary, compiled with
+# Path to the googletest-catch-exceptions-ex-test_ binary, compiled with
 # exceptions enabled.
 EX_EXE_PATH = gtest_test_utils.GetTestExecutablePath(